@@ -19,11 +19,12 @@ package org.apache.tika.parser;
 import java.io.ByteArrayInputStream;
 import java.io.InputStream;
 import java.io.Reader;
-import org.apache.tika.io.IOUtils;
+
 import org.apache.tika.metadata.Metadata;
 import org.apache.tika.metadata.TikaCoreProperties;
 import org.junit.Test;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.junit.Assert.assertEquals;
 
 public class ParsingReaderTest {
@@ -31,7 +32,7 @@ public class ParsingReaderTest {
     @Test
     public void testPlainText() throws Exception {
         String data = "test content";
-        InputStream stream = new ByteArrayInputStream(data.getBytes(IOUtils.UTF_8));
+        InputStream stream = new ByteArrayInputStream(data.getBytes(UTF_8));
         Reader reader = new ParsingReader(stream, "test.txt");
         assertEquals('t', reader.read());
         assertEquals('e', reader.read());
@@ -54,7 +55,7 @@ public class ParsingReaderTest {
     @Test
     public void testXML() throws Exception {
         String data = "<p>test <span>content</span></p>";
-        InputStream stream = new ByteArrayInputStream(data.getBytes(IOUtils.UTF_8));
+        InputStream stream = new ByteArrayInputStream(data.getBytes(UTF_8));
         Reader reader = new ParsingReader(stream, "test.xml");
         assertEquals(' ', (char) reader.read());
         assertEquals('t', (char) reader.read());
@@ -86,9 +87,8 @@ public class ParsingReaderTest {
         Metadata metadata = new Metadata();
         InputStream stream = ParsingReaderTest.class.getResourceAsStream(
                 "/test-documents/testEXCEL.xls");
-        Reader reader = new ParsingReader(
-                new AutoDetectParser(), stream, metadata, new ParseContext());
-        try {
+        try (Reader reader = new ParsingReader(
+                new AutoDetectParser(), stream, metadata, new ParseContext())) {
             // Metadata should already be available
             assertEquals("Simple Excel document", metadata.get(TikaCoreProperties.TITLE));
             // Check that the internal buffering isn't broken
@@ -98,9 +98,13 @@ public class ParsingReaderTest {
             assertEquals('i', (char) reader.read());
             assertEquals('l', (char) reader.read());
             assertEquals('1', (char) reader.read());
-        } finally {
-            reader.close();
         }
     }
 
+    @Test
+    public void testZeroByte() throws Exception {
+        InputStream is = new ByteArrayInputStream(new byte[0]);
+        ParsingReader r = new ParsingReader(is);
+        assertEquals(-1, r.read());
+    }
 }
